add_unique_identifiers_to_df: Add unique identifiers to a single events data frame

View source: R/pipeline-loadasc.R

add_unique_identifiers_to_dfR Documentation

Add unique identifiers to a single events data frame

Description

This function is called by the exposed wrapper load_asc()

Usage

add_unique_identifiers_to_df(events_df)

Arguments

events_df

A single events data frame

Value

Updated events data frame with text_unique column


eyeris documentation built on June 19, 2026, 9:08 a.m.