Helper function to calculate confounds for epoched timeseries data.
This function is used internally by both summarize_confounds()
and epoch().
calculate_epoched_confounds(eyeris, epoch_names, hz, verbose = TRUE)An updated eyeris object with epoched confounds
An object of class eyeris derived from load_asc()
A vector of epoch names to process
The sampling rate
A flag to indicate whether to print progress messages