check_epoch_manual_input_data: Check epoch manual input data structure

View source: R/utils-checks.R

check_epoch_manual_input_dataR Documentation

Check epoch manual input data structure

Description

Validates that the events argument is a list of two data frames.

Usage

check_epoch_manual_input_data(ts_list)

Arguments

ts_list

A list containing both start and end timestamp data frames

Value

No return value; throws error if structure is invalid


eyeris documentation built on June 19, 2026, 9:08 a.m.