check_epoch_manual_input_dfs: Check epoch manual input data frame format

View source: R/utils-checks.R

check_epoch_manual_input_dfsR Documentation

Check epoch manual input data frame format

Description

Validates that start and end timestamp data frames have required columns.

Usage

check_epoch_manual_input_dfs(ts_list)

Arguments

ts_list

A list containing start and end timestamp data frames

Value

No return value; throws error if format is invalid


eyeris documentation built on Aug. 1, 2026, 1:07 a.m.