draw_random_epochs: Draw random epochs for plotting

View source: R/plot.eyeris.R

draw_random_epochsR Documentation

Draw random epochs for plotting

Description

Generates random time segments from the time series data for preview plotting.

Usage

draw_random_epochs(x, n, d, hz)

Arguments

x

A data frame containing time series data

n

Number of random epochs to draw

d

Duration of each epoch in seconds

hz

Sampling rate in Hz

Value

A list of data frames, each containing a random epoch segment


eyeris documentation built on June 19, 2026, 9:08 a.m.