Extracts baseline periods from time series data based on event messages and time ranges or start/end messages.
extract_baseline_epochs(x, df, evs, time_range, matched_epochs, hz)A list of baseline epoch data frames
An eyeris object containing the latest pupil column pointer
The time series data frame
Event messages for baseline extraction
Time range for baseline extraction
Matched epoch start/end times
Sampling rate in Hz