View source: R/utils-database.R
| eyeris_db_summary | R Documentation |
Provides a quick overview of the contents of an eyeris database,
including available subjects, sessions, tasks, and data types.
eyeris_db_summary(bids_dir, db_path = "my-project", verbose = TRUE)
bids_dir |
Path to the BIDS directory containing the database |
db_path |
Database name (defaults to "my-project", becomes "my-project.eyerisdb") |
verbose |
Logical. Whether to print detailed output (default TRUE) |
A named list containing summary information about the database contents
demo_data <- eyelink_asc_demo_dataset()
demo_data |>
eyeris::glassbox() |>
eyeris::epoch(
events = "PROBE_{startstop}_{trial}",
limits = c(-1, 1),
label = "prePostProbe"
) |>
eyeris::bidsify(
bids_dir = file.path(tempdir(), "my-cool-memory-project"),
participant_id = "001",
session_num = "01",
task_name = "assocret",
run_num = "03", # override default run-01 (block_1) to use run-03 instead
db_enabled = TRUE,
db_path = "my-cool-memory-study",
)
# get database summary
summary <- eyeris_db_summary(
file.path(
tempdir(),
"my-cool-memory-project"
),
db_path = "my-cool-memory-study"
)
# view available subjects
summary$subjects
# view available data types
summary$data_types
# view table counts
summary$table_counts
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.