View source: R/pipeline-interpolate.R
| interpolate_pupil | R Documentation |
This function fills missing values (NAs) in pupil data using linear
interpolation. It uses the zoo::na.approx() function with settings
optimized for pupillometry data.
interpolate_pupil(x, prev_op, verbose, max_gap_ms = 250)
x |
A data frame containing the pupil time series data |
prev_op |
The name of the previous operation's output column |
verbose |
A flag to indicate whether to print detailed logging messages |
max_gap_ms |
The maximum duration (in milliseconds) of a gap of missing
( |
Gaps longer than max_gap_ms milliseconds are left as NA rather than
interpolated. The threshold is converted from milliseconds to a number of
samples using the sampling period of the data (estimated from time_orig),
so it is robust to different sampling rates.
This function is called by the exposed wrapper interpolate().
A vector of interpolated pupil values with the same length as the input
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.