is_binocular_object: Check if object is a binocular eyeris object

View source: R/utils-checks.R

is_binocular_objectR Documentation

Check if object is a binocular eyeris object

Description

Detects whether an object is a binocular eyeris object created with binocular_mode = "both".

Usage

is_binocular_object(x)

Arguments

x

The eyeris object to check

Value

Logical indicating whether the object is a binocular eyeris object


eyeris documentation built on June 19, 2026, 9:08 a.m.