make_gap_filter_provenance_note: Build a data-provenance note when filtering ran over long...

View source: R/utils-render_report.R

make_gap_filter_provenance_noteR Documentation

Build a data-provenance note when filtering ran over long interpolation gaps

Description

If lpfilt() and/or downsample() were run on data that still contained gaps left as NA by interpolate(max_gap_ms), those steps filtered over the gaps (temporarily filling and then re-masking them), which can slightly bias the valid samples adjacent to each gap. This records that fact as a "Data Quality Notes" section in the HTML report so it is part of the preprocessing provenance.

Usage

make_gap_filter_provenance_note(eyeris)

Arguments

eyeris

An eyeris object

Value

A markdown string for the report (empty string if no such filtering over gaps occurred, or if max_gap_ms is not a single finite numeric value)


eyeris documentation built on Aug. 1, 2026, 1:07 a.m.