prompt_user: Prompt user for continuation

View source: R/pipeline-glassbox.R

prompt_userR Documentation

Prompt user for continuation

Description

Prompts the user to continue or cancel the current operation.

Usage

prompt_user()

Value

A logical flag indicating whether the user chose to continue


eyeris documentation built on June 19, 2026, 9:08 a.m.