should_omit_parameter: Check if a parameter should be omitted from call stack...

View source: R/utils-parsers.R

should_omit_parameterR Documentation

Check if a parameter should be omitted from call stack display

Description

Determines if a parameter should be omitted when formatting call stacks to avoid memory issues with large epoch-related data structures.

Usage

should_omit_parameter(name, val)

Arguments

name

The parameter name

val

The parameter value

Value

TRUE if the parameter should be omitted, FALSE otherwise


eyeris documentation built on June 19, 2026, 9:08 a.m.