View source: R/pipeline-loadgeneric.R
| standardize_events | R Documentation |
Coerces an optional events data frame to the canonical time/text columns
used internally by eyeris, scaling timestamps to milliseconds.
standardize_events(events, mapping, ms_scale)
events |
Optional events data frame (or |
mapping |
Resolved column-name mapping list. |
ms_scale |
Numeric factor to convert timestamps to milliseconds. |
A data frame with time and text columns (zero-row if events is
NULL).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.