Creates a zip file containing epoch images instead of saving individual files. This function collects all the image data in memory and then creates a single zip file, which can be more efficient for the HTML gallery display.
create_epoch_images_zip(
epochs_to_save,
epoch_index,
block_name,
run_dir_num,
epochs_out,
pupil_steps,
eyeris_object,
eye_suffix = NULL,
report_epoch_grouping_var_col = "matched_event",
verbose = FALSE
)Path to the created zip file
List of epoch data to save
Index of the current epoch being processed
Name of the current block being processed
Run directory number
Output directory for the epoch files
Vector of pupil processing steps
The full eyeris object (needed for screen dimensions)
Optional eye suffix for binocular data
Column name for grouping epochs
Whether to print verbose output