View source: R/pipeline-detrend.R
| detrend | R Documentation |
Linearly detrend_pupil data by fitting a linear model of pupil_data ~ time,
and return the fitted betas and the residuals (pupil_data - fitted_values).
detrend(eyeris, call_info = NULL)
eyeris |
An object of class |
call_info |
A list of call information and parameters. If not provided,
it will be generated from the function call. Defaults to |
This function is automatically called by glassbox() if detrend = TRUE.
Users should prefer using glassbox() rather than invoking this function
directly unless they have a specific reason to customize the pipeline
manually.
An eyeris object with two new columns in time series:
detrend_fitted_betas, and pupil_raw_{...}_detrend
This function is part of the glassbox() preprocessing pipeline and is not
intended for direct use in most cases. Use glassbox(detrend = TRUE).
Advanced users may call it directly if needed.
glassbox() for the recommended way to run this step as
part of the full eyeris glassbox preprocessing pipeline
For a complete, end-to-end reference pipeline that demonstrates how all
eyeris preprocessing functions are chained together in practice, see the
"Building Blocks Under the Hood" section of the Anatomy of an eyeris
Object vignette — vignette("anatomy", package = "eyeris") — as
well as the Complete Pupillometry Pipeline Walkthrough vignette:
vignette("complete-pipeline", package = "eyeris").
demo_data <- eyelink_asc_demo_dataset()
demo_data |>
eyeris::glassbox(detrend = TRUE) |> # set to FALSE to skip step (default)
plot(seed = 0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.