This function detrends pupil data by fitting a linear model
of pupil_data ~ time, and returning the fitted betas and the residuals
(pupil_data - fitted_values).
This function is called by the exposed wrapper detrend().
detrend_pupil(x, prev_op)A list containing the fitted values, coefficients, and residuals
A data frame containing pupil data with columns time_secs and
the previous operation's pupil column
The name of the previous operation's pupil column