View source: R/utils-render_report.R
| filter_task_run_dirs | R Documentation |
Given a vector of directory basenames (as returned by list.dirs(..., full.names = FALSE)), keep only the valid run directories that belong to
task. When task is NULL (or empty), only legacy task-less run-XX
directories are kept. Comparison of the task component is done by exact
string equality (not regex), so task names containing regex metacharacters
or underscores are handled correctly.
filter_task_run_dirs(dirs, task = NULL)
dirs |
Character vector of directory basenames |
task |
Optional BIDS task name. Defaults to |
The subset of dirs belonging to task
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.