This function fills missing values (NAs) in pupil data using linear
interpolation. It uses the zoo::na.approx() function with settings
optimized for pupillometry data.
interpolate_pupil(x, prev_op, verbose)A vector of interpolated pupil values with the same length as the input
A data frame containing the pupil time series data
The name of the previous operation's output column
A flag to indicate whether to print detailed logging messages
This function is called by the exposed wrapper interpolate().