| modal_value | R Documentation |
Returns the most common value in a vector. Used to infer the expected inter-sample interval directly from the data in a way that is robust to a minority of irregular intervals (e.g., dropped samples).
modal_value(x)
x |
A numeric vector. |
The most frequently occurring (finite) value in x, or NA_real_
if x contains no finite values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.