View source: R/pipeline-resample.R
| resample_block | R Documentation |
Places one block's samples onto the expected uniform sampling grid:
interpolates values for sub-period timing jitter and inserts NA rows at
longer-than-expected gaps (dropped samples).
resample_block(block_df, block_label = NULL, verbose = TRUE)
block_df |
A single block's timeseries data frame (must contain a
|
block_label |
Optional character label used in messages |
verbose |
A flag to indicate whether to print detailed logging messages |
This function is called by the exposed wrapper resample().
The block data frame placed on a uniform grid, with inserted (gap)
rows marked in a logical is_resampled column. Returned unchanged (with no
is_resampled column added) when no reconstruction is needed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.