| slice_epoch_window | R Documentation |
Extracts the rows of df whose time_secs fall within
[start_secs, start_secs + d) and (re)computes a time_scaled column (in
milliseconds, relative to the window start). Used to draw a full-resolution
preview epoch over the same time window selected on the decimated data.
slice_epoch_window(df, start_secs, d)
df |
A data frame containing a |
start_secs |
The start of the window in seconds |
d |
The window duration in seconds |
A data frame containing the rows that fall within the window
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.