View source: R/pipeline-loadgeneric.R
| standardize_blinks | R Documentation |
Coerces an optional blinks data frame to the canonical stime/etime
columns used internally by eyeris, scaling timestamps to milliseconds.
standardize_blinks(blinks, mapping, ms_scale)
blinks |
Optional blinks data frame (or |
mapping |
Resolved column-name mapping list. |
ms_scale |
Numeric factor to convert timestamps to milliseconds. |
A data frame with stime and etime columns (zero-row if blinks
is NULL).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.